
#ifndef QGPGME_EXPORT_H
#define QGPGME_EXPORT_H

#ifdef QGPGME_STATIC_DEFINE
#  define QGPGME_EXPORT
#  define QGPGME_NO_EXPORT
#else
#  ifndef QGPGME_EXPORT
#    ifdef KF5QGpgme_EXPORTS
        /* We are building this library */
#      define QGPGME_EXPORT __declspec(dllexport)
#    else
        /* We are using this library */
#      define QGPGME_EXPORT __declspec(dllimport)
#    endif
#  endif

#  ifndef QGPGME_NO_EXPORT
#    define QGPGME_NO_EXPORT 
#  endif
#endif

#ifndef QGPGME_DEPRECATED
#  define QGPGME_DEPRECATED __attribute__ ((__deprecated__))
#endif

#ifndef QGPGME_DEPRECATED_EXPORT
#  define QGPGME_DEPRECATED_EXPORT QGPGME_EXPORT QGPGME_DEPRECATED
#endif

#ifndef QGPGME_DEPRECATED_NO_EXPORT
#  define QGPGME_DEPRECATED_NO_EXPORT QGPGME_NO_EXPORT QGPGME_DEPRECATED
#endif

#if 0 /* DEFINE_NO_DEPRECATED */
#  ifndef QGPGME_NO_DEPRECATED
#    define QGPGME_NO_DEPRECATED
#  endif
#endif

#endif
